@@ -410,9 +410,29 @@ def run(
     if dna_or_rna == "RNA":
         strandness = True
 
-    ensembl_genome = pyensembl.EnsemblRelease(
-        release=release, species=reference
-    )
+    if reference in ["mouse", "GRCm38"]:
+        ensembl_genome = pyensembl.EnsemblRelease(
+            release="108", species="mus_musculus"
+        )
+    elif reference in ["GRCm39"]:
+        ensembl_genome = pyensembl.EnsemblRelease(
+            release="108", species="mus_musculus"
+        )
+    elif reference in ["GRCz11"]:
+        ensembl_genome = pyensembl.EnsemblRelease(
+            release="108", species="danio_rerio"
+        )
+    elif reference in ["human", "GRCh38"]:
+        ensembl_genome = pyensembl.EnsemblRelease(
+            release="108", species="homo_sapiens"
+        )
+    else:
+        if release:
+            ensembl_genome = pyensembl.EnsemblRelease(
+                release=release, species=reference
+            )
+        else:
+            ensembl_genome = pyensembl.EnsemblRelease(species=reference)
     try:
         ensembl_genome.index()
     except:
@@ -428,7 +448,11 @@ def run(
         else:
             input_header = ["chrom", "pos", "strand", "ref", "alt"]
 
-        print("#" + "\t".join(input_header + annot_header), file=output_file)
+        output_file.write(
+            ("" if with_header else "#")
+            + "\t".join(input_header + annot_header)
+            + "\n"
+        )
         for l in input_file:
             input_cols = l.strip("\n").split("\t")
             if len(input_cols) >= 5:
@@ -460,9 +484,8 @@ def run(
             )
             for annot in annot_list:
                 annot_str = list(map(str, annot))
-                print(
-                    "\t".join([c, p, s, ref, alt] + annot_str),
-                    file=output_file,
+                output_file.write(
+                    "\t".join([c, p, s, ref, alt] + annot_str) + "\n"
                 )
 
 
